==> deps-plus-0.1.0-20220810.181056-4.jar: META-INF/leiningen/com.circleci/deps-plus/project.clj <==
(defproject com.circleci/deps-plus "0.1.0-SNAPSHOT"
  :plugins [[jonase/eastwood "0.3.6" :exclusions [org.clojure/clojure]]]

  :pedantic? :abort

  :managed-dependencies [[org.clojure/clojure "1.10.1"]]

  :profiles {:dev {:dependencies [[org.clojure/clojure]
                                  [lambdaisland/kaocha "0.0-601"]
                                  [lambdaisland/kaocha-cloverage "0.0-41"]
                                  [lambdaisland/kaocha-junit-xml "0.0-70"]]}
             :provided {:dependencies [[org.clojure/clojure]
                                       [com.google.guava/guava "30.0-jre"]
                                       [org.jsoup/jsoup "1.14.2"]
                                       [leiningen/leiningen "2.9.1"]]}}

  :aliases {"test"    ["run" "-m" "kaocha.runner"]
            "test-ci" ["test"
                       "--plugin" "cloverage"
                       "--plugin" "kaocha.plugin/profiling"
                       "--plugin" "kaocha.plugin/junit-xml"
                       "--junit-xml-file" "target/test-results/results.xml"]}
  :repositories [["releases" {:url "https://clojars.org/repo"
                              :username :env/clojars_username
                              :password :env/clojars_token
                              :sign-releases false}]
                 ["snapshots" {:url "https://clojars.org/repo"
                               :username :env/clojars_username
                               :password :env/clojars_token
                               :sign-releases false}]])

==> deps-plus-0.1.0-20250826.181942-6.jar: META-INF/leiningen/com.circleci/deps-plus/project.clj <==
(defproject com.circleci/deps-plus "0.1.0-SNAPSHOT"
  :license {:name "Eclipse Public License 1.0"
            :url "https://github.com/circleci/lein-deps-plus/blob/main/LICENSE"
            :distribution :repo}
  :pedantic? :abort

  :managed-dependencies [[org.clojure/clojure "1.10.1"]]

  :profiles {:dev {:dependencies [[org.clojure/clojure]
                                  [lambdaisland/kaocha "1.91.1392"]
                                  [lambdaisland/kaocha-cloverage "1.1.89"]
                                  [lambdaisland/kaocha-junit-xml "1.17.101"]]}
             :provided {:dependencies [[org.clojure/clojure]
                                       [com.google.guava/guava "32.0.1-jre"]
                                       [org.jsoup/jsoup "1.15.3"]
                                       [leiningen/leiningen "2.11.2" :exclusions [nrepl org.slf4j/slf4j-api]]]}}

  :aliases {"test"    ["run" "-m" "kaocha.runner"]
            "test-ci" ["test"
                       "--plugin" "cloverage"
                       "--plugin" "kaocha.plugin/profiling"
                       "--plugin" "kaocha.plugin/junit-xml"
                       "--junit-xml-file" "target/test-results/results.xml"]}
  :repositories [["releases" {:url "https://clojars.org/repo"
                              :username :env/clojars_username
                              :password :env/clojars_token
                              :sign-releases false}]
                 ["snapshots" {:url "https://clojars.org/repo"
                               :username :env/clojars_username
                               :password :env/clojars_token
                               :sign-releases false}]])
